
package com.madhu.xml;

import java.io.*;

import org.w3c.dom.*;
import javax.xml.parsers.*;

public class DocBuilder {
	protected DocumentBuilder docBuilder;
	protected Element root;
	protected Document doc;
	protected PrintWriter writer;

	public DocBuilder() throws Exception {
		DocumentBuilderFactory dbf = DocumentBuilderFactory.newInstance();
		docBuilder = dbf.newDocumentBuilder();
	}

	public void buildDOM(String startDir) throws Exception {
		doc = docBuilder.newDocument();
		root = doc.createElement("directory-listing");
		appendFile(root, new File(startDir));
		doc.appendChild(root);
	}

	public void appendFile(Node parent, File aFile) throws Exception {
		if (aFile.isDirectory()) {
			Element dirElement = doc.createElement("directory");
			dirElement.setAttribute("name", aFile.getName());
			File[] files = aFile.listFiles();
			int n = files.length;
			for (int i=0; i<n; i+=1) {
				appendFile(dirElement, files[i]);
			}
			parent.appendChild(dirElement);
		} else {
			Element fileElement = doc.createElement("file");
			Text fileName = doc.createTextNode(aFile.getName());
			fileElement.appendChild(fileName);
			parent.appendChild(fileElement);
		}
	}

	public void writeDOM(PrintWriter bw) throws Exception {
		writer = bw;
		writer.println("<?xml version=\"1.0\" encoding=\"UTF-8\"?>");
		writeNode("", root);
	}

	public void writeNode(String indent, Node aNode) {
		switch (aNode.getNodeType()) {
			case Node.TEXT_NODE:
				writer.println(indent + aNode.getNodeValue());
				break;

			case Node.ELEMENT_NODE:
				writer.print(indent + "<" + aNode.getNodeName());
				NamedNodeMap attrs = aNode.getAttributes();
				int n = attrs.getLength();
				for (int i=0; i<n; i+=1) {
					Node attr = attrs.item(i);
					writer.print(" " + attr.getNodeName() + "=\"");
					writer.print(attr.getNodeValue() + "\"");
				}
				writer.println(">");
				Node child = aNode.getFirstChild();
				while (child != null) {
					writeNode(indent + "\t", child);
					child = child.getNextSibling();
				}
				writer.println(indent + "</" + aNode.getNodeName() + ">");
				break;
		}
	}

	public static void main(String args[]) throws Exception {
		DocBuilder db = new DocBuilder();
		db.buildDOM(args[0]);
		PrintWriter bw = new PrintWriter(
			new FileWriter(args[1]));
		db.writeDOM(bw);
		bw.close();
	}
}
