
package com.madhu.xml;

import java.io.*;

import org.w3c.dom.*;
import org.w3c.dom.ranges.*;
import javax.xml.parsers.*;

public class RangeApp {
	protected DocumentBuilder docBuilder;
	protected Document document;
	protected Element root;
	protected PrintStream writer;

	public RangeApp() throws Exception {
		DocumentBuilderFactory dbf = DocumentBuilderFactory.newInstance();
		docBuilder = dbf.newDocumentBuilder();
		DOMImplementation domImp = docBuilder.getDOMImplementation();
		if (domImp.hasFeature("Range", "2.0")) {
			System.out.println("Parser supports Range");
		}
	}

	public void parse(String fileName) throws Exception {
		document = docBuilder.parse(new FileInputStream(fileName));
		root = document.getDocumentElement();
		System.out.println("Root element is " + root.getNodeName());
	}

	public void deleteRange() {
		Range r = ((DocumentRange)document).createRange();
		r.selectNodeContents(root.getFirstChild());
		r.deleteContents();
	}

	public void writeDOM(PrintStream bw) throws Exception {
		writer = bw;
		writer.println("<?xml version=\"1.0\" encoding=\"UTF-8\"?>");
		writeNode("", root);
	}

	public void writeNode(String indent, Node aNode) {
		switch (aNode.getNodeType()) {
			case Node.TEXT_NODE:
				writer.println(indent + aNode.getNodeValue());
				break;

			case Node.ELEMENT_NODE:
				writer.print(indent + "<" + aNode.getNodeName());
				NamedNodeMap attrs = aNode.getAttributes();
				int n = attrs.getLength();
				for (int i=0; i<n; i+=1) {
					Node attr = attrs.item(i);
					writer.print(" " + attr.getNodeName() + "=\"");
					writer.print(attr.getNodeValue() + "\"");
				}
				writer.println(">");
				Node child = aNode.getFirstChild();
				while (child != null) {
					writeNode(indent + "\t", child);
					child = child.getNextSibling();
				}
				writer.println(indent + "</" + aNode.getNodeName() + ">");
				break;
		}
	}

	public static void main(String args[]) throws Exception {
		RangeApp ra = new RangeApp();
		ra.parse(args[0]);
		ra.deleteRange();
		ra.writeDOM(System.out);
	}
}
